<?php

/**
 * SMS Gateway handler class
 *
 * @author weDevs
 */
class WeDevs_dokan_SMS_Gateways
{

    private static $_instance;

    /**
     * Gateway slug
     *
     * @param string $provider name of the gateway
     */
    function __construct()
    {
        add_filter('wedevs_sms_via_smsglobal', array($this, 'smsGlobalAPI'));
        add_filter('wedevs_sms_via_clickatell', array($this, 'clickatellAPI'));
        add_filter('wedevs_sms_via_twilio', array($this, 'twilio_api'));
        add_filter('wedevs_sms_via_nexmo', array($this, 'nexmo_api'));
        add_filter('wedevs_sms_via_idehpayam', array($this, 'idehpayam_api'));

    }

    public static function instance()
    {
        if (!self::$_instance) {
            self::$_instance = new WeDevs_dokan_SMS_Gateways();
        }

        return self::$_instance;
    }

    /**
     * Get all sms gateways
     *
     * @return array
     */
    function get_gateways()
    {
        $gateways = array(
            'idehpayam' => array('label' => 'ایده پیام')
        );
        return apply_filters('wedevs_dokan_sms_gateways', $gateways);
    }

    /**
     * Check for sms send throttleing
     * Users should not request for sms frquently
     *
     * @return bool false means not send sms now
     */
    function check_throttle()
    {
        $offset = (int)wedevs_sms_get_option('sms_throttle_offset'); //minutes
        $sms_throttle = wedevs_sms_get_option('sms_throttle');

        //not enabled? bail out
        if ($sms_throttle != 'on') {
            return true;
        }

        //check users
        if (is_user_logged_in()) {
            $last_sent = get_user_meta(get_current_user_id(), 'sms_last_sent', true);
        } else {
            $last_sent = isset($_COOKIE['sms_last_sent']) ? $_COOKIE['sms_last_sent'] : 1;
        }

        if ($last_sent) {
            $last_sent = strtotime($last_sent) + $offset * 60;
            if ((time() - $last_sent) > 0) {
                return true;
            }
        }

        return false;
    }

    function set_last_sent()
    {
        $last_sent = current_time('mysql');

        if (is_user_logged_in()) {
            update_user_meta(get_current_user_id(), 'sms_last_sent', $last_sent);
        } else {
            setcookie('sms_last_sent', $last_sent, time() + 86400, '/');
        }
    }

    function send($to)
    {

        $active_gateway = dokan_get_option('active_gateway', 'dokan_verification_sms_gateways');

        if (empty($active_gateway)) {
            $response = array(
                'success' => false,
                'message' => 'No active gateway found'
            );

            return $response;
        }

        $code = rand(1000, 9999);
//        $sms_text = wedevs_sms_get_option( 'sms_text' );
        $sms_text = dokan_get_option('sms_text', 'dokan_verification_sms_gateways');
        $sms_text = str_replace('%CODE%', $code, $sms_text);
        $sms_data = array('text' => $sms_text, 'to' => $to, 'code' => $code);

        $status = apply_filters('wedevs_sms_via_' . $active_gateway, $sms_data);
        //set last sms sent time
        if ($status['success'] == true) {
            $this->set_last_sent($status);
        }

        if (!isset($status['success'])) {
            $response = array(
                'success' => false,
                'message' => 'Gateway Not found!!!'
            );
            return $response;
        }

        return $status;
    }



		/** NEW ADDED **/
    function idehpayam_api($sms_data)
    {
        $token = dokan_get_option('idehpayam_token', 'dokan_verification_sms_gateways');
        $from = dokan_get_option('idehpayam_from', 'dokan_verification_sms_gateways');
        $pattern = dokan_get_option('idehpayam_pattern', 'dokan_verification_sms_gateways');

		if ( empty( $token ) )
			return $response;

			$massage = json_encode(array('verification-code'=>$sms_data['code']),JSON_UNESCAPED_UNICODE);
			$soap = new SoapClient( "http://185.112.33.61/wbs/send.php?wsdl" );
			$result = $soap->SendSMSByPattern($from,array($sms_data['to']),$massage,$pattern,0,$token);
			if ( ! empty( $result[0] ) && $result[0] > 100 ) {

            $response = array(
                'success' => true,
                'code' => $sms_data['code'],
                'message' => 'کد تایید برای شما ارسال شد!',
            );


			} else {

            $response = array(
                'success' => false,
                'message' => 'حین ارسال پیامک مشکلی رخ داده است!!!'
            );
					
			}
        return $response;

    }
		/** NEW ADDED **/
}
